@@ -33,6 +33,20 @@ kern_return_t __pfinet_siocgifconf
 	mach_msg_type_number_t *bufCnt
 );
 
+/* Routine pfinet_getroutes */
+#ifdef	mig_external
+mig_external
+#else
+extern
+#endif
+kern_return_t __pfinet_getroutes
+(
+	io_t port,
+	vm_size_t amount,
+	data_t *routes,
+	mach_msg_type_number_t *routesCnt
+);
+
 
 /* Module pfinet */
 
@@ -66,4 +80,18 @@ kern_return_t pfinet_siocgifconf
 	mach_msg_type_number_t *bufCnt
 );
 
+/* Routine pfinet_getroutes */
+#ifdef	mig_external
+mig_external
+#else
+extern
+#endif
+kern_return_t pfinet_getroutes
+(
+	io_t port,
+	vm_size_t amount,
+	data_t *routes,
+	mach_msg_type_number_t *routesCnt
+);
+
 #endif	/* not defined(_pfinet_user_) */
