@@ -54,10 +54,10 @@ extern
 kern_return_t __proc_setexecdata
 (
 	process_t process,
-	portarray_t ports,
+	const_portarray_t ports,
 	mach_msg_type_name_t portsPoly,
 	mach_msg_type_number_t portsCnt,
-	intarray_t ints,
+	const_intarray_t ints,
 	mach_msg_type_number_t intsCnt
 );
 
@@ -111,9 +111,9 @@ kern_return_t __proc_register_version
 (
 	process_t process,
 	mach_port_t credential,
-	string_t name,
-	string_t release,
-	string_t version
+	const_string_t name,
+	const_string_t release,
+	const_string_t version
 );
 
 /* SimpleRoutine proc_reauthenticate */
@@ -125,8 +125,8 @@ extern
 kern_return_t __proc_reauthenticate
 (
 	process_t process,
-	mach_port_t rendezvous2,
-	mach_msg_type_name_t rendezvous2Poly
+	mach_port_t rendezvous,
+	mach_msg_type_name_t rendezvousPoly
 );
 
 /* Routine proc_child */
@@ -274,7 +274,7 @@ kern_return_t __proc_handle_exceptions
 	mach_port_t forwardport,
 	mach_msg_type_name_t forwardportPoly,
 	int flavor,
-	thread_state_t new_state,
+	const thread_state_t new_state,
 	mach_msg_type_number_t new_stateCnt
 );
 
@@ -505,7 +505,7 @@ extern
 kern_return_t __proc_setlogin
 (
 	process_t process,
-	string_t logname
+	const_string_t logname
 );
 
 /* Routine proc_getlogin */
@@ -733,7 +733,7 @@ extern
 kern_return_t __proc_set_exe
 (
 	process_t process,
-	string_t path
+	const_string_t path
 );
 
 /* Routine proc_get_exe */
@@ -773,6 +773,48 @@ kern_return_t __proc_get_entry
 	vm_address_t *entry
 );
 
+/* Routine proc_waitid */
+#ifdef	mig_external
+mig_external
+#else
+extern
+#endif
+kern_return_t __proc_waitid
+(
+	process_t process,
+	pid_t pid,
+	int options,
+	int *status,
+	int *sigcode,
+	rusage_t *rusage,
+	pid_t *pid_status
+);
+
+/* SimpleRoutine proc_reauthenticate_reassign */
+#ifdef	mig_external
+mig_external
+#else
+extern
+#endif
+kern_return_t __proc_reauthenticate_reassign
+(
+	process_t old_process,
+	mach_port_t rendezvous,
+	mach_msg_type_name_t rendezvousPoly,
+	mach_port_t new_task
+);
+
+/* SimpleRoutine proc_reauthenticate_complete */
+#ifdef	mig_external
+mig_external
+#else
+extern
+#endif
+kern_return_t __proc_reauthenticate_complete
+(
+	process_t process
+);
+
 
 /* Module process */
 
@@ -827,10 +869,10 @@ extern
 kern_return_t proc_setexecdata
 (
 	process_t process,
-	portarray_t ports,
+	const_portarray_t ports,
 	mach_msg_type_name_t portsPoly,
 	mach_msg_type_number_t portsCnt,
-	intarray_t ints,
+	const_intarray_t ints,
 	mach_msg_type_number_t intsCnt
 );
 
@@ -884,9 +926,9 @@ kern_return_t proc_register_version
 (
 	process_t process,
 	mach_port_t credential,
-	string_t name,
-	string_t release,
-	string_t version
+	const_string_t name,
+	const_string_t release,
+	const_string_t version
 );
 
 /* SimpleRoutine proc_reauthenticate */
@@ -898,8 +940,8 @@ extern
 kern_return_t proc_reauthenticate
 (
 	process_t process,
-	mach_port_t rendezvous2,
-	mach_msg_type_name_t rendezvous2Poly
+	mach_port_t rendezvous,
+	mach_msg_type_name_t rendezvousPoly
 );
 
 /* Routine proc_child */
@@ -1047,7 +1089,7 @@ kern_return_t proc_handle_exceptions
 	mach_port_t forwardport,
 	mach_msg_type_name_t forwardportPoly,
 	int flavor,
-	thread_state_t new_state,
+	const thread_state_t new_state,
 	mach_msg_type_number_t new_stateCnt
 );
 
@@ -1278,7 +1320,7 @@ extern
 kern_return_t proc_setlogin
 (
 	process_t process,
-	string_t logname
+	const_string_t logname
 );
 
 /* Routine proc_getlogin */
@@ -1506,7 +1548,7 @@ extern
 kern_return_t proc_set_exe
 (
 	process_t process,
-	string_t path
+	const_string_t path
 );
 
 /* Routine proc_get_exe */
@@ -1546,4 +1588,46 @@ kern_return_t proc_get_entry
 	vm_address_t *entry
 );
 
+/* Routine proc_waitid */
+#ifdef	mig_external
+mig_external
+#else
+extern
+#endif
+kern_return_t proc_waitid
+(
+	process_t process,
+	pid_t pid,
+	int options,
+	int *status,
+	int *sigcode,
+	rusage_t *rusage,
+	pid_t *pid_status
+);
+
+/* SimpleRoutine proc_reauthenticate_reassign */
+#ifdef	mig_external
+mig_external
+#else
+extern
+#endif
+kern_return_t proc_reauthenticate_reassign
+(
+	process_t old_process,
+	mach_port_t rendezvous,
+	mach_msg_type_name_t rendezvousPoly,
+	mach_port_t new_task
+);
+
+/* SimpleRoutine proc_reauthenticate_complete */
+#ifdef	mig_external
+mig_external
+#else
+extern
+#endif
+kern_return_t proc_reauthenticate_complete
+(
+	process_t process
+);
+
 #endif	/* not defined(_process_user_) */
