@@ -53,10 +53,10 @@ kern_return_t __proc_setexecdata_request
 (
 	process_t process,
 	mach_port_t reply,
-	portarray_t ports,
+	const_portarray_t ports,
 	mach_msg_type_name_t portsPoly,
 	mach_msg_type_number_t portsCnt,
-	intarray_t ints,
+	const_intarray_t ints,
 	mach_msg_type_number_t intsCnt
 );
 
@@ -109,9 +109,9 @@ kern_return_t __proc_register_version_request
 	process_t process,
 	mach_port_t reply,
 	mach_port_t credential,
-	string_t name,
-	string_t release,
-	string_t version
+	const_string_t name,
+	const_string_t release,
+	const_string_t version
 );
 
 /* SimpleRoutine proc_reauthenticate_request */
@@ -124,8 +124,8 @@ kern_return_t __proc_reauthenticate_request
 (
 	process_t process,
 	mach_port_t reply,
-	mach_port_t rendezvous2,
-	mach_msg_type_name_t rendezvous2Poly
+	mach_port_t rendezvous,
+	mach_msg_type_name_t rendezvousPoly
 );
 
 /* SimpleRoutine proc_child_request */
@@ -273,7 +273,7 @@ kern_return_t __proc_handle_exceptions_request
 	mach_port_t forwardport,
 	mach_msg_type_name_t forwardportPoly,
 	int flavor,
-	thread_state_t new_state,
+	const thread_state_t new_state,
 	mach_msg_type_number_t new_stateCnt
 );
 
@@ -506,7 +506,7 @@ kern_return_t __proc_setlogin_request
 (
 	process_t process,
 	mach_port_t reply,
-	string_t logname
+	const_string_t logname
 );
 
 /* SimpleRoutine proc_getlogin_request */
@@ -780,10 +780,10 @@ kern_return_t proc_setexecdata_request
 (
 	process_t process,
 	mach_port_t reply,
-	portarray_t ports,
+	const_portarray_t ports,
 	mach_msg_type_name_t portsPoly,
 	mach_msg_type_number_t portsCnt,
-	intarray_t ints,
+	const_intarray_t ints,
 	mach_msg_type_number_t intsCnt
 );
 
@@ -836,9 +836,9 @@ kern_return_t proc_register_version_request
 	process_t process,
 	mach_port_t reply,
 	mach_port_t credential,
-	string_t name,
-	string_t release,
-	string_t version
+	const_string_t name,
+	const_string_t release,
+	const_string_t version
 );
 
 /* SimpleRoutine proc_reauthenticate_request */
@@ -851,8 +851,8 @@ kern_return_t proc_reauthenticate_request
 (
 	process_t process,
 	mach_port_t reply,
-	mach_port_t rendezvous2,
-	mach_msg_type_name_t rendezvous2Poly
+	mach_port_t rendezvous,
+	mach_msg_type_name_t rendezvousPoly
 );
 
 /* SimpleRoutine proc_child_request */
@@ -1000,7 +1000,7 @@ kern_return_t proc_handle_exceptions_request
 	mach_port_t forwardport,
 	mach_msg_type_name_t forwardportPoly,
 	int flavor,
-	thread_state_t new_state,
+	const thread_state_t new_state,
 	mach_msg_type_number_t new_stateCnt
 );
 
@@ -1233,7 +1233,7 @@ kern_return_t proc_setlogin_request
 (
 	process_t process,
 	mach_port_t reply,
-	string_t logname
+	const_string_t logname
 );
 
 /* SimpleRoutine proc_getlogin_request */
