@@ -22,7 +22,7 @@ kern_return_t __exception_raise
 	mach_port_t task,
 	integer_t exception,
 	integer_t code,
-	integer_t subcode
+	rpc_long_integer_t subcode
 );
 
 
@@ -47,7 +47,7 @@ kern_return_t exception_raise
 	mach_port_t task,
 	integer_t exception,
 	integer_t code,
-	integer_t subcode
+	rpc_long_integer_t subcode
 );
 
 #endif	/* not defined(_exc_user_) */
