@@ -23,11 +23,11 @@ kern_return_t _S_catch_exception_raise
 	mach_port_t task,
 	integer_t exception,
 	integer_t code,
-	integer_t subcode
+	rpc_long_integer_t subcode
 );
 
 extern mig_routine_t _S_exc_server_routines[];
-static inline mig_routine_t _S_exc_server_routine
+static __inline mig_routine_t _S_exc_server_routine
 	(const mach_msg_header_t *InHeadP)
 {
 	int msgh_id;
