@@ -124,7 +124,7 @@ kern_return_t __thread_set_state
 (
 	mach_port_t target_thread,
 	int flavor,
-	thread_state_t new_state,
+	const thread_state_t new_state,
 	mach_msg_type_number_t new_stateCnt
 );
 
@@ -731,7 +731,7 @@ kern_return_t thread_set_state
 (
 	mach_port_t target_thread,
 	int flavor,
-	thread_state_t new_state,
+	const thread_state_t new_state,
 	mach_msg_type_number_t new_stateCnt
 );
 
